@@ -8,7 +8,8 @@ FutureRegistry <- local({
     NA_integer_
   }
 
-  function(where, action=c("add", "remove", "list", "collect-first"), future=NULL, ...) {
+  function(where, action=c("add", "remove", "list", "collect-first", "reset"), future=NULL, ...) {
+    stopifnot(length(where) == 1, nzchar(where))
     futures <- db[[where]]
 
     ## Automatically create?
@@ -20,14 +21,18 @@ FutureRegistry <- local({
     if (action == "add") {
       idx <- indexOf(futures, future=future)
       if (!is.na(idx)) {
-        stop(sprintf("Cannot add to %s registry. %s is already registered.", sQuote(where), class(future)[1]))
+        msg <- sprintf("Cannot add to %s registry. %s is already registered.", sQuote(where), class(future)[1])
+        mdebug("ERROR: %s", msg)
+        stop(msg)
       }
       futures[[length(futures)+1L]] <- future
       db[[where]] <<- futures
     } else if (action == "remove") {
       idx <- indexOf(futures, future=future)
       if (is.na(idx)) {
-        stop(sprintf("Cannot remove from %s registry. %s not registered.", sQuote(where), class(future)[1]))
+        msg <- sprintf("Cannot remove from %s registry. %s not registered.", sQuote(where), class(future)[1])
+        mdebug("ERROR: %s", msg)
+        stop(msg)
       }
       futures[[idx]] <- NULL
       db[[where]] <<- futures
@@ -54,10 +59,14 @@ FutureRegistry <- local({
 	  break
 	}
       }
+    } else if (action == "reset") {
+      db[[where]] <<- list()
     } else if (action == "list") {
       return(futures)
     } else {
-      stop(sprintf("INTERNAL ERROR: Unknown action to %s registry: %s", sQuote(where), action))
+      msg <- sprintf("INTERNAL ERROR: Unknown action to %s registry: %s", sQuote(where), action)
+      mdebug(msg)
+      stop(msg)
     }
   }
 })
