@@ -16,19 +16,6 @@ This will attempt to port the code to standard Py3 code that also
 provides Py2 compatibility with the help of the right imports from
 ``future``. To write the changes to disk, use the -w flag.
 
-Or, to make existing Python 3 code compatible with both Python 2 and 3
-using the ``future`` package:
-
-  $ futurize --from3 --verbose mypython3script.py
-
-which removes any Py3-only syntax (e.g. new metaclasses) and adds these
-import lines:
-
-    from __future__ import (absolute_import, division,
-                            print_function, unicode_literals)
-    from future import standard_library
-    from future.builtins import *
-
 To write changes to the files, use the -w flag.
 
 Two stages
@@ -71,11 +58,10 @@ import optparse
 from lib2to3.main import main, warn, StdoutRefactoringTool
 from lib2to3 import refactor
 
-from libfuturize.fixes2 import (lib2to3_fix_names_stage1,
-                                lib2to3_fix_names_stage2,
-                                libfuturize_2fix_names_stage1,
-                                libfuturize_2fix_names_stage2)
-from libfuturize.fixes3 import libfuturize_3fix_names
+from libfuturize.fixes import (lib2to3_fix_names_stage1,
+                               lib2to3_fix_names_stage2,
+                               libfuturize_fix_names_stage1,
+                               libfuturize_fix_names_stage2)
 
 
 def main(args=None):
@@ -97,8 +83,8 @@ def main(args=None):
                       help="Take modernized (stage1) code and add a dependency on ``future`` to provide Py3 compatibility.")
     parser.add_option("-0", "--both-stages", action="store_true",
                       help="Apply both stages 1 and 2")
-    # parser.add_option("-f", "--fix", action="append", default=[],
-    #                   help="Each FIX specifies a transformation; default: all")
+    parser.add_option("-f", "--fix", action="append", default=[],
+                      help="Each FIX specifies a transformation; default: all")
     parser.add_option("-j", "--processes", action="store", default=1,
                       type="int", help="Run 2to3 concurrently")
     parser.add_option("-x", "--nofix", action="append", default=[],
@@ -115,37 +101,27 @@ def main(args=None):
                       help="Write back modified files")
     parser.add_option("-n", "--nobackups", action="store_true", default=False,
                       help="Don't write backups for modified files.")
-    parser.add_option("--from3", action="store_true", default=False,
-                      help="Assume the code is already Python 3 and just "
-                           "requires ``__future__`` and ``future`` imports.")
 
     # Parse command line arguments
     refactor_stdin = False
     flags = {}
     options, args = parser.parse_args(args)
-    if options.from3:
-        assert not (options.stage1 or options.stage2)
-        assert not options.tobytes
-        fixer_pkg = 'libfuturize.fixes3'
-        avail_fixes = libfuturize_3fix_names
-        flags["print_function"] = True
+    fixer_pkg = 'libfuturize.fixes'
+    avail_fixes = set()
+    if not (options.stage1 or options.stage2):
+        options.both_stages = True
     else:
-        fixer_pkg = 'libfuturize.fixes2'
-        avail_fixes = set()
-        if not (options.stage1 or options.stage2):
-            options.both_stages = True
-        else:
-            assert options.both_stages is None
-            options.both_stages = False
-        if options.stage1 or options.both_stages:
-            avail_fixes.update(lib2to3_fix_names_stage1)
-            avail_fixes.update(libfuturize_2fix_names_stage1)
-        if options.stage2 or options.both_stages:
-            avail_fixes.update(lib2to3_fix_names_stage2)
-            avail_fixes.update(libfuturize_2fix_names_stage2)
+        assert options.both_stages is None
+        options.both_stages = False
+    if options.stage1 or options.both_stages:
+        avail_fixes.update(lib2to3_fix_names_stage1)
+        avail_fixes.update(libfuturize_fix_names_stage1)
+    if options.stage2 or options.both_stages:
+        avail_fixes.update(lib2to3_fix_names_stage2)
+        avail_fixes.update(libfuturize_fix_names_stage2)
 
     if options.tobytes:
-        avail_fixes.add('libfuturize.fixes2.fix_bytes')
+        avail_fixes.add('libfuturize.fixes.fix_bytes')
     if not options.write and options.no_diffs:
         warn("not writing files and not printing diffs; that's not very useful")
     if not options.write and options.nobackups:
@@ -167,8 +143,7 @@ def main(args=None):
             print("Can't write to stdin.", file=sys.stderr)
             return 2
 
-    # If this option were ever needed, it would probably mean the --from3 flag
-    # had been forgotten.
+    # Is this ever necessary?
     # if options.print_function:
     #     flags["print_function"] = True
 
@@ -186,7 +161,7 @@ def main(args=None):
     # further.)
     extra_fixes = set()
     if options.all_imports:
-        prefix = 'libfuturize.fixes2.'
+        prefix = 'libfuturize.fixes.'
         if options.stage1:
             extra_fixes.add(prefix +
                             'fix_add__future__imports_except_unicode_literals')
