@@ -4,6 +4,8 @@ ovars <- ls()
 oopts <- options(warn=1)
 plan(lazy)
 
+message("*** future() ...")
+
 f <- future({
   42L
 })
@@ -13,6 +15,7 @@ y <- value(f)
 print(y)
 stopifnot(y == 42L)
 
+message("*** future() ... DONE")
 
 ## Cleanup
 plan(eager)
